@@ -10,8 +10,8 @@ class AccessToken:
         self.audience = audience
         self.value = token
 
-    async def refresh(self):
-        self.value = str(await self.credentials.exchange(self.audience))
+    async def refresh(self, scope: set):
+        self.value = str(await self.credentials.exchange(self.audience, scope))
 
 
     def __str__(self) -> str:
